@@ -74,7 +74,7 @@ send_response (AccessDialogHandle *handle)
       const char *key;
       GtkWidget *widget;
 
-      g_variant_builder_init (&choice_builder, G_VARIANT_TYPE_VARDICT);
+      g_variant_builder_init (&choice_builder, G_VARIANT_TYPE ("a(ss)"));
       g_hash_table_iter_init (&iter, handle->choices);
       while (g_hash_table_iter_next (&iter, (gpointer *)&key, (gpointer *)&widget))
         {
@@ -86,7 +86,7 @@ send_response (AccessDialogHandle *handle)
                 continue;
 
               str = g_strsplit (key, ":", -1);
-              g_variant_builder_add (&choice_builder, "{sv}", str[0], g_variant_new_string (str[1]));
+              g_variant_builder_add (&choice_builder, "(ss)", str[0], str[1]);
               g_strfreev (str);
             }
           else if (GTK_IS_CHECK_BUTTON (widget))
@@ -94,7 +94,7 @@ send_response (AccessDialogHandle *handle)
               gboolean active;
 
               active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
-              g_variant_builder_add (&choice_builder, "{sv}", key, g_variant_new_string (active ? "true" : "false"));
+              g_variant_builder_add (&choice_builder, "(ss)", key, active ? "true" : "false");
             }
         }
 
@@ -329,7 +329,15 @@ handle_access_dialog (XdpImplAccess *object,
       body_label = gtk_label_new (arg_body);
       gtk_widget_set_halign (body_label, GTK_ALIGN_START);
       g_object_set (body_label, "margin-top", 10, NULL);
+#if GTK_CHECK_VERSION (3,16,0)
       gtk_label_set_xalign (GTK_LABEL (body_label), 0);
+#else
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+      /* This is deprecated in 3.14, but gtk_label_set_xalign() is not
+       * available until 3.16. */
+      gtk_misc_set_alignment (GTK_MISC (body_label), 0.0, 0.5);
+G_GNUC_END_IGNORE_DEPRECATIONS
+#endif
       gtk_label_set_line_wrap (GTK_LABEL (body_label), TRUE);
       gtk_label_set_max_width_chars (GTK_LABEL (body_label), 50);
       gtk_widget_show (body_label);
