@@ -25,11 +25,11 @@ main (int argc, char *argv[])
         int i;
         const char *default_id = NULL;
         const char *content_type = NULL;
-        const char *filename = NULL;
+        const char *location = NULL;
         GOptionEntry entries[] = {
           { "default", 0, 0, G_OPTION_ARG_STRING, &default_id, "The default choice", "ID" },
           { "content-type", 0, 0, G_OPTION_ARG_STRING, &content_type, "The content type", "TYPE" },
-          { "filename", 0, 0, G_OPTION_ARG_STRING, &filename, "The filename", "FILE" },
+          { "location", 0, 0, G_OPTION_ARG_STRING, &location, "The location (file or uri)", "LOCATION" },
           { NULL, }
         };
 
@@ -40,7 +40,7 @@ main (int argc, char *argv[])
                 apps[i] = argv[i + 1];
         apps[argc - 1] = NULL;
 
-        window = GTK_WIDGET (app_chooser_dialog_new (apps, default_id, content_type, filename));
+        window = GTK_WIDGET (app_chooser_dialog_new (apps, default_id, content_type, location));
         g_signal_connect (window, "close", G_CALLBACK (close_cb), NULL);
 
         gtk_widget_show (window);
